]> git.mxchange.org Git - friendica.git/blobdiff - index.php
revup
[friendica.git] / index.php
index 5f128ebb1b4754a9615a97d244d3bcc1b7db2dce..05eef6c6e0bfe0f2e7475b29798ff96866702e6d 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,5 +1,7 @@
 <?php
 
+error_reporting(E_ERROR | E_WARNING | E_PARSE);
+
 /**
  *
  * Friendika
@@ -19,11 +21,11 @@ $a = new App;
 /**
  *
  * Load the configuration file which contains our DB credentials.
- * Ignore errors. If the file doesn't exist, we are running in installation mode.
+ * Ignore errors. If the file doesn't exist or is empty, we are running in installation mode.
  *
  */
 
-$install = ((file_exists('.htconfig.php')) ? false : true);
+$install = ((file_exists('.htconfig.php') && filesize('.htconfig.php')) ? false : true);
 
 @include(".htconfig.php");
 
@@ -31,10 +33,18 @@ $install = ((file_exists('.htconfig.php')) ? false : true);
  *
  * Get the language setting directly from system variables, bypassing get_config()
  * as database may not yet be configured.
+ * 
+ * If possible, we use the value from the browser.
  *
  */
 
-$lang = ((isset($a->config['system']['language'])) ? $a->config['system']['language'] : 'en');
+if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
+       $langs = preg_split("/[,-]/",$_SERVER['HTTP_ACCEPT_LANGUAGE'],2);
+       $lang = $langs[0];
+} else {
+       $lang = ((isset($a->config['system']['language'])) ? $a->config['system']['language'] : 'en');
+}
+
        
 load_translation_table($lang);
 
@@ -79,6 +89,19 @@ $a->init_pagehead();
 
 session_start();
 
+/**
+ * Language was set earlier, but we can over-ride it in the session.
+ * We have to do it here because the session was just now opened.
+ */
+
+if(x($_POST,'system_language'))
+       $_SESSION['language'] = $_POST['system_language'];
+if((x($_SESSION,'language')) && ($_SESSION['language'] !== $lang)) {
+       $lang = $_SESSION['language'];
+       load_translation_table($lang);
+}
+
+
 /**
  *
  * For Mozilla auth manager - still needs sorting, and this might conflict with LRDD header.
@@ -102,8 +125,9 @@ if(! x($_SESSION,'sysmsg'))
        $_SESSION['sysmsg'] = '';
 
 /*
* check_config() is responible for running update scripts. These automatically 
* update the DB schema whenever  we push a new one out. 
  */
 
 
@@ -113,9 +137,16 @@ else
        check_config($a);
 
 
+$arr = array('app_menu' => $a->apps);
+
+call_hooks('app_menu', $arr);
+
+$a->apps = $arr['app_menu'];
+
+
 /**
  *
- * We have already parsed the server path into $->argc and $a->argv
+ * We have already parsed the server path into $a->argc and $a->argv
  *
  * $a->argv[0] is our module name. We will load the file mod/{$a->argv[0]}.php
  * and use it for handling our URL request.
@@ -123,7 +154,7 @@ else
  * and in the following order:
  * 
  * "module"_init
- * "module"_post (only if there are $_POST variables)
+ * "module"_post (only called if there are $_POST variables)
  * "module"_afterpost
  * "module"_content - the string return of this function contains our page body
  *
@@ -132,13 +163,44 @@ else
  * further processing.
  */
 
-
 if(strlen($a->module)) {
-       if(file_exists("mod/{$a->module}.php")) {
-               include("mod/{$a->module}.php");
+
+       /**
+        *
+        * We will always have a module name.
+        * First see if we have a plugin which is masquerading as a module.
+        *
+        */
+
+       if(is_array($a->plugins) && in_array($a->module,$a->plugins) && file_exists("addon/{$a->module}/{$a->module}.php")) {
+               include_once("addon/{$a->module}/{$a->module}.php");
+               if(function_exists($a->module . '_module'))
+                       $a->module_loaded = true;
+       }
+
+       /**
+        * If not, next look for a 'standard' program module in the 'mod' directory
+        */
+
+       if((! $a->module_loaded) && (file_exists("mod/{$a->module}.php"))) {
+               include_once("mod/{$a->module}.php");
                $a->module_loaded = true;
        }
-       else {
+
+       /**
+        *
+        * The URL provided does not resolve to a valid module.
+        *
+        * On Dreamhost sites, quite often things go wrong for no apparent reason and they send us to '/internal_error.html'. 
+        * We don't like doing this, but as it occasionally accounts for 10-20% or more of all site traffic - 
+        * we are going to trap this and redirect back to the requested page. As long as you don't have a critical error on your page
+        * this will often succeed and eventually do the right thing.
+        *
+        * Otherwise we are going to emit a 404 not found.
+        *
+        */
+
+       if(! $a->module_loaded) {
                if((x($_SERVER,'QUERY_STRING')) && ($_SERVER['QUERY_STRING'] === 'q=internal_error.html') && isset($dreamhost_error_hack)) {
                        logger('index.php: dreamhost_error_hack invoked. Original URI =' . $_SERVER['REQUEST_URI']);
                        goaway($a->get_baseurl() . $_SERVER['REQUEST_URI']);
@@ -150,6 +212,8 @@ if(strlen($a->module)) {
        }
 }
 
+
+
 /* initialise content region */
 
 if(! x($a->page,'content'))
@@ -186,7 +250,7 @@ if($a->module_loaded) {
 
 }
 
-// let javascript take you home
+// If you're just visiting, let javascript take you home
 
 if(x($_SESSION,'visitor_home'))
        $homebase = $_SESSION['visitor_home'];
@@ -234,8 +298,10 @@ $a->page['content'] .=  '<div id="pause"></div>';
  *
  */
 
-if($a->module != 'install')
+if($a->module != 'install') {
        require_once('nav.php');
+       nav($a);
+}
 
 /**
  * Build the page - now that we have all the components
@@ -102,8 +125,9 @@ if(! x($_SESSION,'sysmsg'))
 
 /*
- * check_config() is responible for running update scripts. These automatically 
- * update the DB schema whenever  we push a new one out. 
+ * check_config() is responsible for running update scripts. These automatically 
+ * update the DB schema whenever we push a new one out. It also checks to see if
+ * any plugins have been added or removed and reacts accordingly. 
  */
 